UIPasteboard class abstract
Constructors
- UIPasteboard()
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getChangeCount(
) → Future< int> - https://developer.apple.com/documentation/uikit/uipasteboard/changecount
-
getColor(
) → Future< Color?> - https://developer.apple.com/documentation/uikit/uipasteboard/color
-
getColors(
) → Future< List< Color> ?> - https://developer.apple.com/documentation/uikit/uipasteboard/colors
-
getImage(
) → Future< ByteData?> - https://developer.apple.com/documentation/uikit/uipasteboard/image
-
getImages(
) → Future< List< ByteData> ?> - https://developer.apple.com/documentation/uikit/uipasteboard/images
-
getItems(
) → Future< List< Map< ?>String, dynamic> > - https://developer.apple.com/documentation/uikit/uipasteboard/items
-
getNumberOfItems(
) → Future< int> - https://developer.apple.com/documentation/uikit/uipasteboard/numberofitems
-
getString(
) → Future< String?> - https://developer.apple.com/documentation/uikit/uipasteboard/string
-
getStrings(
) → Future< List< String> ?> - https://developer.apple.com/documentation/uikit/uipasteboard/strings
-
getTypes(
) → Future< List< String> ?> - https://developer.apple.com/documentation/uikit/uipasteboard/types
-
getURL(
) → Future< String?> - https://developer.apple.com/documentation/uikit/uipasteboard/url
-
getURLs(
) → Future< List< String> ?> - https://developer.apple.com/documentation/uikit/uipasteboard/urls
-
hasColors(
) → Future< bool> - https://developer.apple.com/documentation/uikit/uipasteboard/hasColors
-
hasImages(
) → Future< bool> - https://developer.apple.com/documentation/uikit/uipasteboard/hasImages
-
hasStrings(
) → Future< bool> - https://developer.apple.com/documentation/uikit/uipasteboard/strings
-
hasURLs(
) → Future< bool> - https://developer.apple.com/documentation/uikit/uipasteboard/hasurl
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited